@@ -1,5 +1,4 @@
 //go:build !windows
-// +build !windows
 
 package chezmoi
 
@@ -7,19 +6,24 @@ import (
 	"errors"
 	"io/fs"
 	"os"
+	"sync"
 	"syscall"
 
 	"github.com/google/renameio/v2"
 	vfs "github.com/twpayne/go-vfs/v4"
-	"go.uber.org/multierr"
+
+	"github.com/twpayne/chezmoi/v2/internal/chezmoierrors"
 )
 
 // An RealSystem is a System that writes to a filesystem and executes scripts.
 type RealSystem struct {
-	fileSystem   vfs.FS
-	safe         bool
-	devCache     map[AbsPath]uint // devCache maps directories to device numbers.
-	tempDirCache map[uint]string  // tempDirCache maps device numbers to renameio temporary directories.
+	fileSystem              vfs.FS
+	safe                    bool
+	createScriptTempDirOnce sync.Once
+	scriptTempDir           AbsPath
+	scriptEnv               []string
+	devCache                map[AbsPath]uint // devCache maps directories to device numbers.
+	tempDirCache            map[uint]string  // tempDirCache maps device numbers to renameio temporary directories.
 }
 
 // RealSystemWithSafe sets the safe flag of the RealSystem.
@@ -29,6 +33,13 @@ func RealSystemWithSafe(safe bool) RealSystemOption {
 	}
 }
 
+// RealSystemWithScriptTempDir sets the script temporary directory of the RealSystem.
+func RealSystemWithScriptTempDir(scriptTempDir AbsPath) RealSystemOption {
+	return func(s *RealSystem) {
+		s.scriptTempDir = scriptTempDir
+	}
+}
+
 // NewRealSystem returns a System that acts on fileSystem.
 func NewRealSystem(fileSystem vfs.FS, options ...RealSystemOption) *RealSystem {
 	s := &RealSystem{
@@ -83,9 +94,7 @@ func (s *RealSystem) WriteFile(filename AbsPath, data []byte, perm fs.FileMode)
 		if t, err = renameio.TempFile(tempDir, filename.String()); err != nil {
 			return
 		}
-		defer func() {
-			err = multierr.Append(err, t.Cleanup())
-		}()
+		defer chezmoierrors.CombineFunc(&err, t.Cleanup)
 		if err = t.Chmod(perm); err != nil {
 			return
 		}
@@ -106,7 +115,8 @@ func (s *RealSystem) WriteSymlink(oldname string, newname AbsPath) error {
 	if s.safe && s.fileSystem == vfs.OSFS {
 		return renameio.Symlink(oldname, newname.String())
 	}
-	if err := s.fileSystem.RemoveAll(newname.String()); err != nil && !errors.Is(err, fs.ErrNotExist) {
+	if err := s.fileSystem.RemoveAll(newname.String()); err != nil &&
+		!errors.Is(err, fs.ErrNotExist) {
 		return err
 	}
 	return s.fileSystem.Symlink(oldname, newname.String())
@@ -121,13 +131,11 @@ func writeFile(fileSystem vfs.FS, filename AbsPath, data []byte, perm fs.FileMod
 	if f, err = fileSystem.OpenFile(filename.String(), os.O_WRONLY|os.O_CREATE|os.O_TRUNC, perm); err != nil {
 		return
 	}
-	defer func() {
-		err = multierr.Append(err, f.Close())
-	}()
+	defer chezmoierrors.CombineFunc(&err, f.Close)
 
 	// Set permissions after truncation but before writing any data, in case the
 	// file contained private data before, but before writing the new contents,
-	// in case the contents contain private data after.
+	// in case the new contents contain private data after.
 	if err = f.Chmod(perm); err != nil {
 		return
 	}
