@@ -4,13 +4,17 @@ import (
 	"errors"
 	"io/fs"
 	"path/filepath"
+	"sync"
 
 	vfs "github.com/twpayne/go-vfs/v4"
 )
 
 // An RealSystem is a System that writes to a filesystem and executes scripts.
 type RealSystem struct {
-	fileSystem vfs.FS
+	fileSystem              vfs.FS
+	createScriptTempDirOnce sync.Once
+	scriptEnv               []string
+	scriptTempDir           AbsPath
 }
 
 // RealSystemWithSafe sets the safe flag of the RealSystem. On Windows it does
@@ -21,11 +25,20 @@ func RealSystemWithSafe(safe bool) RealSystemOption {
 	return func(s *RealSystem) {}
 }
 
+// RealSystemWithScriptTempDir sets the script temporary directory of the RealSystem.
+func RealSystemWithScriptTempDir(scriptTempDir AbsPath) RealSystemOption {
+	return func(s *RealSystem) {}
+}
+
 // NewRealSystem returns a System that acts on fs.
 func NewRealSystem(fileSystem vfs.FS, options ...RealSystemOption) *RealSystem {
-	return &RealSystem{
+	s := &RealSystem{
 		fileSystem: fileSystem,
 	}
+	for _, option := range options {
+		option(s)
+	}
+	return s
 }
 
 // Chmod implements System.Chmod.
@@ -49,7 +62,8 @@ func (s *RealSystem) WriteFile(filename AbsPath, data []byte, perm fs.FileMode)
 
 // WriteSymlink implements System.WriteSymlink.
 func (s *RealSystem) WriteSymlink(oldname string, newname AbsPath) error {
-	if err := s.fileSystem.RemoveAll(newname.String()); err != nil && !errors.Is(err, fs.ErrNotExist) {
+	if err := s.fileSystem.RemoveAll(newname.String()); err != nil &&
+		!errors.Is(err, fs.ErrNotExist) {
 		return err
 	}
 	return s.fileSystem.Symlink(filepath.FromSlash(oldname), newname.String())
