@@ -5,11 +5,11 @@ import (
 	"bytes"
 	"context"
 	"io"
+	"io/fs"
 	"testing"
 
+	"github.com/alecthomas/assert/v2"
 	"github.com/coreos/go-semver/semver"
-	"github.com/stretchr/testify/assert"
-	"github.com/stretchr/testify/require"
 	vfs "github.com/twpayne/go-vfs/v4"
 
 	"github.com/twpayne/chezmoi/v2/internal/chezmoitest"
@@ -18,16 +18,16 @@ import (
 var _ System = &TarWriterSystem{}
 
 func TestTarWriterSystem(t *testing.T) {
-	chezmoitest.WithTestFS(t, map[string]interface{}{
-		"/home/user/.local/share/chezmoi": map[string]interface{}{
+	chezmoitest.WithTestFS(t, map[string]any{
+		"/home/user/.local/share/chezmoi": map[string]any{
 			".chezmoiignore":  "README.md\n",
 			".chezmoiremove":  "*.txt\n",
 			".chezmoiversion": "1.2.3\n",
-			".chezmoitemplates": map[string]interface{}{
+			".chezmoitemplates": map[string]any{
 				"template": "# contents of .chezmoitemplates/template\n",
 			},
 			"README.md": "",
-			"dot_dir": map[string]interface{}{
+			"dot_dir": map[string]any{
 				"file": "# contents of .dir/file\n",
 			},
 			"run_script":      "# contents of script\n",
@@ -38,6 +38,7 @@ func TestTarWriterSystem(t *testing.T) {
 		system := NewRealSystem(fileSystem)
 		s := NewSourceState(
 			WithBaseSystem(system),
+			WithDestDir(NewAbsPath("/home/user")),
 			WithSourceDir(NewAbsPath("/home/user/.local/share/chezmoi")),
 			WithSystem(system),
 			WithVersion(semver.Version{
@@ -46,16 +47,19 @@ func TestTarWriterSystem(t *testing.T) {
 				Patch: 3,
 			}),
 		)
-		require.NoError(t, s.Read(ctx, nil))
+		assert.NoError(t, s.Read(ctx, nil))
 		requireEvaluateAll(t, s, system)
 
 		b := &bytes.Buffer{}
 		tarWriterSystem := NewTarWriterSystem(b, tar.Header{})
 		persistentState := NewMockPersistentState()
-		require.NoError(t, s.applyAll(tarWriterSystem, system, persistentState, EmptyAbsPath, ApplyOptions{
-			Include: NewEntryTypeSet(EntryTypesAll),
-		}))
-		require.NoError(t, tarWriterSystem.Close())
+		assert.NoError(
+			t,
+			s.applyAll(tarWriterSystem, system, persistentState, EmptyAbsPath, ApplyOptions{
+				Filter: NewEntryTypeFilter(EntryTypesAll, EntryTypesNone),
+			}),
+		)
+		assert.NoError(t, tarWriterSystem.Close())
 
 		r := tar.NewReader(b)
 		for _, tc := range []struct {
@@ -68,7 +72,7 @@ func TestTarWriterSystem(t *testing.T) {
 			{
 				expectedTypeflag: tar.TypeDir,
 				expectedName:     ".dir/",
-				expectedMode:     0o777 &^ int64(chezmoitest.Umask),
+				expectedMode:     int64(fs.ModePerm &^ chezmoitest.Umask),
 			},
 			{
 				expectedTypeflag: tar.TypeReg,
@@ -90,7 +94,7 @@ func TestTarWriterSystem(t *testing.T) {
 		} {
 			t.Run(tc.expectedName, func(t *testing.T) {
 				header, err := r.Next()
-				require.NoError(t, err)
+				assert.NoError(t, err)
 				assert.Equal(t, tc.expectedTypeflag, header.Typeflag)
 				assert.Equal(t, tc.expectedName, header.Name)
 				assert.Equal(t, tc.expectedMode, header.Mode)
@@ -98,7 +102,7 @@ func TestTarWriterSystem(t *testing.T) {
 				assert.Equal(t, int64(len(tc.expectedContents)), header.Size)
 				if tc.expectedContents != nil {
 					actualContents, err := io.ReadAll(r)
-					require.NoError(t, err)
+					assert.NoError(t, err)
 					assert.Equal(t, tc.expectedContents, actualContents)
 				}
 			})
