@@ -3,6 +3,8 @@ package cmd
 import (
 	"errors"
 	"strings"
+
+	"github.com/twpayne/chezmoi/v2/internal/chezmoi"
 )
 
 // A readDataFormat is a format that chezmoi uses for reading (JSON, TOML, or
@@ -24,10 +26,19 @@ const (
 
 	writeDataFormatJSON writeDataFormat = "json"
 	writeDataFormatYAML writeDataFormat = "yaml"
-
-	defaultWriteDataFormat = writeDataFormatJSON
 )
 
+var readDataFormatFlagCompletionFunc = chezmoi.FlagCompletionFunc([]string{
+	string(readDataFormatJSON),
+	string(readDataFormatTOML),
+	string(readDataFormatYAML),
+})
+
+var writeDataFormatFlagCompletionFunc = chezmoi.FlagCompletionFunc([]string{
+	string(writeDataFormatJSON),
+	string(writeDataFormatYAML),
+})
+
 // Set implements github.com/spf13/pflag.Value.Set.
 func (f *readDataFormat) Set(s string) error {
 	switch strings.ToLower(s) {
@@ -43,6 +54,11 @@ func (f *readDataFormat) Set(s string) error {
 	return nil
 }
 
+// Format returns f's format.
+func (f readDataFormat) Format() chezmoi.Format {
+	return chezmoi.FormatsByName[string(f)]
+}
+
 // String implements github.com/spf13/pflag.Value.String.
 func (f readDataFormat) String() string {
 	return string(f)
@@ -53,6 +69,11 @@ func (f readDataFormat) Type() string {
 	return "json|toml|yaml"
 }
 
+// Format returns f's format.
+func (f writeDataFormat) Format() chezmoi.Format {
+	return chezmoi.FormatsByName[string(f)]
+}
+
 // Set implements github.com/spf13/pflag.Value.Set.
 func (f *writeDataFormat) Set(s string) error {
 	switch strings.ToLower(s) {
